==> ukui-panel_4.10.1.5.orig.tar.gz: ukui-panel-4.10.1.5/panel/src/view/panel.h <==
/*
 * Copyright (C) 2024, KylinSoft Co., Ltd.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * Authors: hxf <hewenfei@kylinos.cn>
 *          iaom <zhangpengfei@kylinos.cn>
 */

#ifndef UKUI_PANEL_PANEL_H
#define UKUI_PANEL_PANEL_H

#include <QQuickView>
#include <QScreen>
#include <QRect>
#include <QTimer>
#include <types.h>
#include <window-helper.h>
#include <island-view.h>
#include "screens-manager.h"
#include "general-config-define.h"

class QAction;

namespace UkuiPanel {

/**
 * 屏幕不可用区域
 * 一般存在于屏幕四周
 */
class UnavailableArea
{
public:
    int leftWidth = 0;
    int leftStart = 0;
    int leftEnd = 0;
    int rightWidth = 0;
    int rightStart = 0;
    int rightEnd = 0;
    int topWidth = 0;
    int topStart = 0;
    int topEnd = 0;
    int bottomWidth = 0;
    int bottomStart = 0;
    int bottomEnd = 0;
};

class Panel : public UkuiQuick::IslandView
{
    Q_OBJECT
    Q_PROPERTY(bool lockPanel READ lockPanel NOTIFY lockPanelChanged)
    Q_PROPERTY(bool enableCustomSize READ enableCustomSize NOTIFY enableCustomSizeChanged)
public:
    Panel(Screen *screen, const QString &id, QWindow *parent = nullptr);
    void setPanelScreen(Screen *screen);

    bool lockPanel() const;
    bool enableCustomSize() const;
    Q_INVOKABLE void customPanelSize(bool isAdd);
    Q_INVOKABLE void changeCursor(const QString &type);
    Q_INVOKABLE void changePanelPos(UkuiQuick::Types::Pos pos);

Q_SIGNALS:
    void lockPanelChanged();
    void enableCustomSizeChanged();

protected:
    bool event(QEvent *e) override;

private Q_SLOTS:
    void onScreenGeometryChanged(const QRect &geometry);
    void setPosition(UkuiQuick::Types::Pos position);
    void setPanelSize(int size);
    void setPanelPolicy(GeneralConfigDefine::PanelSizePolicy sizePolicy);
    void setAutoHide(bool autoHide);

    void resetWorkArea(bool cut);
    void setHidden(bool hidden);
    void activeHideTimer(bool active = true);

    void setLockPanel(bool locked, bool noEmit = false);
    // widget opt
    void widgetActionTriggered(const QAction *);
    void disableWidget(const QString &id, bool disable);
    void onContainerActiveChanged();

private:
    void initConfig();
    void initPanelConfig();
    void loadWidgetsConfig();
    void initWidgets();
    void updateGeometry();
    void refreshRect();

    void loadActions();
    void initSizeAction();
    void updateSizeAction();
    void initPositionAction();
    void updatePositionAction();
    void updateMask();
    void initIsland();

private:
    int m_panelSize {48};
    GeneralConfigDefine::PanelSizePolicy m_sizePolicy {GeneralConfigDefine::Small};
    QString m_id;
    Screen *m_screen {nullptr};

    QAction *m_sizeAction {nullptr};
    QAction *m_positionAction {nullptr};
    QAction *m_lockPanelAction {nullptr};
    QAction *m_autoHideAction {nullptr};
    QList<QAction*> m_widgetActions;
    QStringList m_disabledWidgets;

    bool m_autoHide = true;
    bool m_isHidden = true;
    bool m_lockPanel = false;
    QTimer *m_hideTimer = nullptr;
    UnavailableArea m_unavailableArea;
    UkuiQuick::WindowProxy *m_windowProxy = nullptr;
};

} // UkuiPanel

Q_DECLARE_METATYPE(QList<int>)

#endif //UKUI_PANEL_PANEL_H

==> ukui-panel_4.10.3.1.orig.tar.gz: ukui-panel-4.10.3.1/panel/src/view/panel.h <==
/*
 * Copyright (C) 2024, KylinSoft Co., Ltd.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * Authors: hxf <hewenfei@kylinos.cn>
 *          iaom <zhangpengfei@kylinos.cn>
 */

#ifndef UKUI_PANEL_PANEL_H
#define UKUI_PANEL_PANEL_H

#include <QQuickView>
#include <QScreen>
#include <QRect>
#include <QTimer>
#include <types.h>
#include <window-helper.h>
#include <island-view.h>
#include "screens-manager.h"
#include "general-config-define.h"
#include "common.h"

class QAction;

namespace UkuiPanel {

class Panel : public UkuiQuick::IslandView
{
    Q_OBJECT
    Q_PROPERTY(bool lockPanel READ lockPanel NOTIFY lockPanelChanged)
    Q_PROPERTY(bool enableCustomSize READ enableCustomSize NOTIFY enableCustomSizeChanged)
public:
    Panel(Screen *screen, const QString &id, QWindow *parent = nullptr);
    void setPanelScreen(Screen *screen);

    bool lockPanel() const;
    bool enableCustomSize() const;
    Q_INVOKABLE void customPanelSize(int distance);
    Q_INVOKABLE void changeCursor(const QString &type);
    Q_INVOKABLE void changePanelPos(UkuiQuick::Types::Pos pos);

Q_SIGNALS:
    void lockPanelChanged();
    void enableCustomSizeChanged();

protected:
    bool event(QEvent *e) override;

private Q_SLOTS:
    void onScreenGeometryChanged(const QRect &geometry);
    void setPosition(UkuiQuick::Types::Pos position);
    void setPanelSize(int size);
    void setPanelPolicy(GeneralConfigDefine::PanelSizePolicy sizePolicy);
    void setAutoHide(bool autoHide);

    void resetWorkArea(bool cut);
    void setHidden(bool hidden);
    void activeHideTimer(bool active = true);

    void setLockPanel(bool locked, bool noEmit = false);
    // widget opt
    void widgetActionTriggered(const QAction *);
    void disableWidget(const QString &id, bool disable);
    void onContainerActiveChanged();

private:
    void initConfig();
    void initPanelConfig();
    void loadWidgetsConfig();
    void updateGeometry();
    void refreshRect();

    void loadActions();
    void initSizeAction();
    void updateSizeAction();
    void initPositionAction();
    void updatePositionAction();
    void initLockPanelAction();
    void updateLockPanelAction();
    void updateMask();
    void initIsland();

private:
    int m_panelSize {48};
    GeneralConfigDefine::PanelSizePolicy m_sizePolicy {GeneralConfigDefine::Small};
    QString m_id;
    Screen *m_screen {nullptr};

    QAction *m_sizeAction {nullptr};
    QAction *m_positionAction {nullptr};
    QAction *m_lockPanelAction {nullptr};
    QAction *m_autoHideAction {nullptr};
    QList<QAction*> m_widgetActions;
    QStringList m_disabledWidgets;

    bool m_autoHide = true;
    bool m_isHidden = true;
    bool m_lockPanel = false;
    QTimer *m_hideTimer = nullptr;
    UnavailableArea m_unavailableArea;
    UkuiQuick::WindowProxy *m_windowProxy = nullptr;
    bool m_containsMouse = false;
    int m_panelMaxSize = 92;
    int m_panelMinSize = 48;
};

} // UkuiPanel

Q_DECLARE_METATYPE(QList<int>)

#endif //UKUI_PANEL_PANEL_H
